M$ModelName = "LQ_S1";

(* 
   
FeynRules model file for S1 = (3,1,-1/3) = S1m13 scalar leptoquark. It is based on the Physics Reports 641 (2016) 1-68. See Eq. (8) of Phys. Rep. for notation. The mass (decay width) of S1 is denoted MS1 (WS1). 

*)

M$Information = {Authors -> {"I. Dorsner", "A. Greljo"}, 
                 Version -> "3.0",
                 Date    -> "03. 12. 2017"};


M$InteractionOrderHierarchy = {
  {QCD, 1},
  {QED, 2},
  {NP,2} 
};


M$Parameters = {
 
(* S1 = S1m13 leptoquark Yukawa couplings *)

yLL == { 
    	ParameterType    -> External,
	ComplexParameter -> False,
    	Indices          -> {Index[Generation], Index[Generation]},
	BlockName        -> YUKS1LL,
    	Value            -> {yLL[1,1] -> 0.1, yLL[1,2] -> 0.1, yLL[1,3] -> 0.1,
                      	     yLL[2,1] -> 0.1, yLL[2,2] -> 0.1, yLL[2,3] -> 0.1,
                             yLL[3,1] -> 0.1, yLL[3,2] -> 0.1, yLL[3,3] -> 0.1},
    	TeX              -> Superscript[y,LL],
	InteractionOrder -> {NP, 1},
    	Description      -> "S1 leptoquark LL Yukawa coupling matrix"
},

yRR == { 
    	ParameterType    -> External,
	ComplexParameter -> False,
    	Indices          -> {Index[Generation], Index[Generation]},
	BlockName        -> YUKS1RR,
    	Value            -> {yRR[1,1] -> 0.1, yRR[1,2] -> 0.1, yRR[1,3] -> 0.1,
                      	     yRR[2,1] -> 0.1, yRR[2,2] -> 0.1, yRR[2,3] -> 0.1,
                             yRR[3,1] -> 0.1, yRR[3,2] -> 0.1, yRR[3,3] -> 0.1},
    	TeX              -> Superscript[y,RR],
	InteractionOrder -> {NP, 1},
    	Description      -> "S1 leptoquark RR Yukawa coupling matrix"
}

};

M$ClassesDescription = {

(******************************************)
(* Scalar singlet S1 = (3,1,-1/3) = S1m13 *)
(******************************************)

(* physical fields *)

S[200] == {
ClassName        -> S1m13,
Mass             -> {MS1, 650},
Width            -> {WS1, 12.93},
SelfConjugate    -> False,
PropagatorLabel  -> "S1m13",
PropagatorType   -> D,
PropagatorArrow  -> None,
QuantumNumbers   -> {Q -> -1/3, LeptonNumber -> 1},
Indices          -> {Index[Colour]},
ParticleName     -> "S1m13",
AntiParticleName -> "S1m13*",
FullName         -> "S1m13"
}

};


(********************* The Lagrangian *********************)


(***** Kinetic term *****)


LS1Kin := Module[ {mu,c},
DC[S1m13bar[c],mu] DC[S1m13[c],mu] - MS1^2 S1m13bar[c] S1m13[c]
];

(***** LQ-quark-lepton interactions *****)

LS1Yuk1 :=  Module[ {a,b,sp,i,j,cc},
 ExpandIndices[yLL[i,j] anti[CC[QL]][sp,a,i,cc].LL[sp,b,j] S1m13bar[cc] Eps[a,b], FlavorExpand->{SU2D,Generation}]
];

LS1Yuk2 :=  Module[ {sp,i,j,cc},
 ExpandIndices[yRR[i,j] anti[CC[uR]][sp,i,cc].lR[sp,j] S1m13bar[cc], FlavorExpand-> Generation]
];


(***** Complete S1 Lagrangian *****)


LS1 := LS1Kin + LS1Yuk1 + HC[LS1Yuk1] + LS1Yuk2 + HC[LS1Yuk2];


(***********************************************************)