M$ModelName = "LO_LQ_S3";

(* 
   
FeynRules model file for S3 = (3,3,-1/3) scalar leptoquark. It is based on the Physics Reports 641 (2016) 1-68. See Eqs. (1) and (2) of Phys. Rep. for notation. S3 has three electric charge eigenstate components denoted S3p23 (Q=+2/3), S3m13 (Q=-1/3), and S3m43 (Q=-4/3) with common mass MS3. The relevant decay widths for S3p23, S3m13, and S3m43 are WS323, WS313, and WS343, respectively. This model file is suitable for the leading order simulations only.

*)

M$Information = {Authors -> {"I. Dorsner", "D. A. Faroughy", "A. Greljo"}, 
                 Version -> "5.0",
                 Date    -> "09.02.2018",
                 Emails  -> {"dorsner@fesb.hr"},
                 URLs    -> "http://lqnlo.hepforge.org"};

M$InteractionOrderHierarchy = {
  {QCD, 1},
  {QED, 2},
  {NP,1}
};

M$Parameters = {

(* S3 leptoquark mass parameter *)

MS3 == { 
        ParameterType -> External,
        BlockName     -> LQPARAM,
        Value         -> 650.0,
        Description   -> "S3 mass"
       },

(* S3 leptoquark Yukawa couplings *)

yLL == { 
        ParameterType    -> External,
	ComplexParameter -> False,
    	Indices          -> {Index[Generation], Index[Generation]},
	BlockName        -> YUKS3LL,
    	Value            -> {yLL[1,1] -> 0.1, yLL[1,2] -> 0.0, yLL[1,3] -> 0.0,
                      	     yLL[2,1] -> 0.0, yLL[2,2] -> 0.0, yLL[2,3] -> 0.0,
                             yLL[3,1] -> 0.0, yLL[3,2] -> 0.0, yLL[3,3] -> 0.0},
    	TeX              -> Superscript[y,LL],
	InteractionOrder -> {NP, 1},
	ComplexParameter -> False, 
    	Description      -> "S3 leptoquark Yukawa coupling matrix"
       },

(* S3 leptoquark multiplet decay widths *)

WS323 == {
   ParameterType -> Internal,
   Value         -> (MS3*(Abs[CKM[1,1]*yLL[1,1]+CKM[1,2]*yLL[2,1]]^2 
                        + Abs[CKM[1,1]*yLL[1,2]+CKM[1,2]*yLL[2,2]]^2 
                        + Abs[CKM[1,1]*yLL[1,3]+CKM[1,2]*yLL[2,3]]^2 
                        + Abs[CKM[2,1]*yLL[1,1]+CKM[2,2]*yLL[2,1]]^2 
                        + Abs[CKM[2,1]*yLL[1,2]+CKM[2,2]*yLL[2,2]]^2 
                        + Abs[CKM[2,1]*yLL[1,3]+CKM[2,2]*yLL[2,3]]^2) 
                       + (Abs[yLL[3,1]]^2 + Abs[yLL[3,2]]^2 + Abs[yLL[3,3]]^2)*(MS3^2-ymt^2)^2/MS3^3)/(8*Pi)
         },
 
WS313 == {
   ParameterType -> Internal,
   Value         -> (MS3*(Abs[yLL[1,1]]^2 + Abs[yLL[1,2]]^2 + Abs[yLL[1,3]]^2 
                        + Abs[yLL[2,1]]^2 + Abs[yLL[2,2]]^2 + Abs[yLL[2,3]]^2
                        + Abs[yLL[3,1]]^2 + Abs[yLL[3,2]]^2 + Abs[yLL[3,3]]^2
                        + Abs[CKM[1,1]*yLL[1,1]+CKM[1,2]*yLL[2,1]]^2 
                        + Abs[CKM[1,1]*yLL[1,2]+CKM[1,2]*yLL[2,2]]^2 
                        + Abs[CKM[1,1]*yLL[1,3]+CKM[1,2]*yLL[2,3]]^2 
                        + Abs[CKM[2,1]*yLL[1,1]+CKM[2,2]*yLL[2,1]]^2 
                        + Abs[CKM[2,1]*yLL[1,2]+CKM[2,2]*yLL[2,2]]^2 
                        + Abs[CKM[2,1]*yLL[1,3]+CKM[2,2]*yLL[2,3]]^2) 
                       + (Abs[yLL[3,1]]^2 + Abs[yLL[3,2]]^2 + Abs[yLL[3,3]]^2)*(MS3^2-ymt^2)^2/MS3^3)/(16*Pi)
         },

WS343 == {
          ParameterType -> Internal,
          Value         -> (MS3*(Abs[yLL[1,1]]^2 + Abs[yLL[1,2]]^2 + Abs[yLL[1,3]]^2 
                               + Abs[yLL[2,1]]^2 + Abs[yLL[2,2]]^2 + Abs[yLL[2,3]]^2 
                               + Abs[yLL[3,1]]^2 + Abs[yLL[3,2]]^2 + Abs[yLL[3,3]]^2))/(8*Pi)
         }

};

M$ClassesDescription = {

(**********************************)
(* Scalar triplet S3 = (3,3,-1/3) *)
(**********************************)

(* physical fields *)

S[100] == {
           ClassName        -> S3p23,
           Mass             -> {MS3, Internal},
           Width            -> {WS323, Internal},
           SelfConjugate    -> False,
           PropagatorLabel  -> "S23",
           PropagatorType   -> D,
           PropagatorArrow  -> None,
           QuantumNumbers   -> {Q -> 2/3, LeptonNumber -> 1},
           Indices          -> {Index[Colour]},
           ParticleName     -> "S3p23",
           AntiParticleName -> "S3p23*",
           FullName         -> "S323"
          },

S[101] == {
           ClassName        -> S3m13,
           Mass             -> {MS3, Internal},
           Width            -> {WS313, Internal},
           SelfConjugate    -> False,
           PropagatorLabel  -> "S13",
           PropagatorType   -> D,
           PropagatorArrow  -> None,
           QuantumNumbers   -> {Q -> -1/3, LeptonNumber -> 1},
           Indices          -> {Index[Colour]},
           ParticleName     -> "S3m13",
           AntiParticleName -> "S3m13*",
           FullName         -> "S313"
          },

S[102] == {
           ClassName        -> S3m43,
           Mass             -> {MS3, Internal},
           Width            -> {WS343, Internal},
           SelfConjugate    -> False,
           PropagatorLabel  -> "S43",
           PropagatorType   -> D,
           PropagatorArrow  -> None,
           QuantumNumbers   -> {Q -> -4/3, LeptonNumber -> 1},
           Indices          -> {Index[Colour]},
           ParticleName     -> "S3m43",
           AntiParticleName -> "S3m43*",
           FullName         -> "S343"
          },

(* unphysical fields *)

S[103] == {
           ClassName      -> S3,
           Unphysical     -> True,
           SelfConjugate  -> False,
           QuantumNumbers -> {Y -> -1/3},
           Indices        -> {Index[SU2W], Index[Colour]},
           FlavorIndex    -> SU2W,
           Definitions    -> {S3[1,cc_] -> (S3m43[cc] + S3p23[cc])/Sqrt[2],
                              S3[2,cc_] -> (S3m43[cc] - S3p23[cc])/(I*Sqrt[2]),
                              S3[3,cc_] ->  S3m13[cc]}
          }
};


(********************* The Lagrangian *********************)


(***** Kinetic term *****)


LS3Kin := Module[ {mu,a,c},
ExpandIndices[DC[S3bar[a,c],mu] DC[S3[a,c],mu] - MS3^2 S3bar[a,c] S3[a,c], FlavorExpand->{SU2W,SU2D}]];


(***** LQ-quark-lepton interactions *****)


LS3Yuk :=  Module[ {a,b,c,sp,i,j,cc,k},
ExpandIndices[yLL[i,j] anti[CC[QL]][sp,a,i,cc].LL[sp,c,j] S3bar[k,cc] 2*Ta[k,b,c] Eps[a,b], FlavorExpand->{SU2W,SU2D,Generation}]
];


(***** Complete S3 Lagrangian *****)


LS3 := LS3Kin + LS3Yuk + HC[LS3Yuk];


(***********************************************************)